@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2020 Greenbone Networks GmbH
+# Copyright (C) 2020-2021 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -274,9 +274,7 @@ class GmpCreateTagTestCase:
         """
         with self.assertRaises(InvalidArgumentType):
             self.gmp.create_tag(
-                name='foo',
-                resource_ids=['foo'],
-                resource_type='INVALID',
+                name='foo', resource_ids=['foo'], resource_type='INVALID'
             )
 
 
