@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2020 Greenbone Networks GmbH
+# Copyright (C) 2020-2021 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -175,8 +175,7 @@ class GmpModifyPolicySetFamilySelectionTestCase:
         )
 
         self.gmp.modify_policy_set_family_selection(
-            policy_id='c1',
-            families=[('foo', False, True)],
+            policy_id='c1', families=[('foo', False, True)]
         )
 
         self.connection.send.has_been_called_with(
